==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-tools/packages/runtime-tools-process-dev-ui-webapp/src/api/RuntimeToolsDevUIEnvelopeApi.ts <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { CustomLabels } from "./CustomLabels";
import { DiagramPreviewSize } from "@kie-tools/runtime-tools-process-enveloped-components/dist/processDetails";

export interface RuntimeToolsDevUIEnvelopeApi {
  runtimeToolsDevUI_initRequest(association: Association, initArgs: RuntimeToolsDevUIInitArgs): Promise<void>;
}

export interface Association {
  origin: string;
  envelopeServerId: string;
}

export interface User {
  id: string;
  groups: string[];
}

export interface RuntimeToolsDevUIInitArgs {
  users?: User[];
  dataIndexUrl: string;
  remoteKogitoAppUrl?: string;
  page: string;
  devUIUrl: string;
  openApiPath: string;
  isDataIndexAvailable: boolean;
  availablePages?: string[];
  customLabels: CustomLabels;
  omittedProcessTimelineEvents?: string[];
  diagramPreviewSize?: DiagramPreviewSize;
}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-tools/packages/runtime-tools-process-dev-ui-webapp/src/api/RuntimeToolsDevUIEnvelopeApi.ts <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { CustomLabels } from "./CustomLabels";
import { DiagramPreviewSize } from "@kie-tools/runtime-tools-process-enveloped-components/dist/processDetails";

export interface RuntimeToolsDevUIEnvelopeApi {
  runtimeToolsDevUI_initRequest(association: Association, initArgs: RuntimeToolsDevUIInitArgs): Promise<void>;
}

export interface Association {
  origin: string;
  envelopeServerId: string;
}

export interface User {
  id: string;
  groups: string[];
}

export interface RuntimeToolsDevUIInitArgs {
  users?: User[];
  dataIndexUrl: string;
  quarkusAppOrigin: string;
  quarkusAppRootPath?: string;
  shouldReplaceQuarkusAppOriginWithWebappOrigin?: boolean;
  page: string;
  devUIOrigin: string;
  devUIUrl: string;
  isDataIndexAvailable: boolean;
  availablePages?: string[];
  customLabels: CustomLabels;
  omittedProcessTimelineEvents?: string[];
  diagramPreviewSize?: DiagramPreviewSize;
}
